@@ -17,7 +17,7 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '2.2.15'
+__version__ = '2.2.17'
 __author__ = 'Celia Oakley'
 __copyright__ = 'Copyright (c) 2013-2020 Celia Oakley'
 __license__ = 'GPLv3'
@@ -34,7 +34,7 @@ from .genres import Genres
 from .movies import Movies, Collections, Companies, Keywords, Reviews
 from .people import People, Credits, Jobs
 from .search import Search
-from .tv import TV, TV_Seasons, TV_Episodes, TV_Changes, Networks
+from .tv import TV, TV_Seasons, TV_Episodes, TV_Episode_Groups, TV_Changes, Networks
 
 
 API_KEY = os.environ.get('TMDB_API_KEY', None)
